class AnsibleCliError(Exception):
    pass


class ProjectError(Exception):
    pass


class CloudCliError(Exception):
    pass


class SpecValidatorError(Exception):
    pass


class TerraformCliError(Exception):
    pass


class TPAexecCliError(Exception):
    pass


class CliError(Exception):
    pass


class VMWareCliError(Exception):
    pass


class VirtualBoxCliError(Exception):
    pass